import pathlib
from setuptools import setup

setup(
    name="ign-lidarutils",
    version="0.0.0",
    description="Lidar utils",
    long_description_content_type="text/markdown",
    author="Guillaume Liégard",
    author_email="guillaume.liegard@ign.fr",
    classifiers=[],
    packages=["lidarutils"],
    include_package_data=True,
)
